from sqlalchemy import (
    Boolean, Column, Date, DateTime, Float, Integer, String, Text, UniqueConstraint
)
from sqlalchemy.ext.declarative import declarative_base
from shared_architecture.utils.custom_types import TimezoneAwareDateTime

Base = declarative_base()

class Symbol(Base):
    __tablename__ = "symbols"
    __table_args__ = (
        UniqueConstraint('instrument_key'),
        {'schema': 'tradingdb'}
    )

    instrument_key = Column(String, primary_key=True)
    stock_token = Column(String)
    instrument_name = Column(String)
    stock_code = Column(String)
    series = Column(String)
    expiry_date = Column(TimezoneAwareDateTime)
    strike_price = Column(Float)
    option_type = Column(String)
    ca_level = Column(String)
    permitted_to_trade = Column(Boolean)
    issue_capital = Column(Float)
    warning_qty = Column(Integer)
    freeze_qty = Column(Integer)
    credit_rating = Column(String)
    normal_market_status = Column(String)
    odd_lot_market_status = Column(String)
    spot_market_status = Column(String)
    auction_market_status = Column(String)
    normal_market_eligibility = Column(String)
    odd_lot_market_eligibility = Column(String)
    spot_market_eligibility = Column(String)
    auction_market_eligibility = Column(String)
    scrip_id = Column(String)
    issue_rate = Column(Float)
    issue_start_date = Column(TimezoneAwareDateTime)
    interest_payment_date = Column(TimezoneAwareDateTime)
    issue_maturity_date = Column(TimezoneAwareDateTime)
    margin_percentage = Column(Float)
    minimum_lot_qty = Column(Integer)
    lot_size = Column(Integer)
    tick_size = Column(Float)
    company_name = Column(String)
    listing_date = Column(TimezoneAwareDateTime)
    expulsion_date = Column(TimezoneAwareDateTime)
    readmission_date = Column(TimezoneAwareDateTime)
    record_date = Column(TimezoneAwareDateTime)
    low_price_range = Column(Float)
    high_price_range = Column(Float)
    security_expiry_date = Column(TimezoneAwareDateTime)
    no_delivery_start_date = Column(TimezoneAwareDateTime)
    no_delivery_end_date = Column(TimezoneAwareDateTime)
    aon = Column(String)
    participant_in_market_index = Column(String)
    book_cls_start_date = Column(TimezoneAwareDateTime)
    book_cls_end_date = Column(TimezoneAwareDateTime)
    excercise_start_date = Column(TimezoneAwareDateTime)
    excercise_end_date = Column(TimezoneAwareDateTime)
    old_token = Column(String)
    asset_instrument = Column(String)
    asset_name = Column(String)
    asset_token = Column(Integer)
    intrinsic_value = Column(Float)
    extrinsic_value = Column(Float)
    excercise_style = Column(String)
    egm = Column(String)
    agm = Column(String)
    interest = Column(String)
    bonus = Column(String)
    rights = Column(String)
    dividends = Column(String)
    ex_allowed = Column(String)
    ex_rejection_allowed = Column(Boolean)
    pl_allowed = Column(Boolean)
    is_this_asset = Column(Boolean)
    is_corp_adjusted = Column(Boolean)
    local_update_datetime = Column(DateTime)
    delete_flag = Column(Boolean)
    remarks = Column(String)
    base_price = Column(Float)
    exchange_code = Column(String)
    product_type = Column(String)
    breeze_token = Column(String)
    kite_token = Column(String)
    board_lot_qty = Column(Integer)
    date_of_delisting = Column(TimezoneAwareDateTime)
    date_of_listing = Column(TimezoneAwareDateTime)
    face_value = Column(Float)
    freeze_percent = Column(Float)
    high_date = Column(TimezoneAwareDateTime)
    isin_code = Column(String)
    instrument_type = Column(String)
    issue_price = Column(Float)
    life_time_high = Column(Float)
    life_time_low = Column(Float)
    low_date = Column(TimezoneAwareDateTime)
    avm_buy_margin = Column(Float)
    avm_sell_margin = Column(Float)
    bcast_flag = Column(Boolean)
    group_name = Column(String)
    market_lot = Column(Integer)
    nde_date = Column(TimezoneAwareDateTime)
    nds_date = Column(TimezoneAwareDateTime)
    nd_flag = Column(Boolean)
    scrip_code = Column(String)
    scrip_name = Column(String)
    susp_status = Column(String)
    suspension_reason = Column(String)
    suspension_date = Column(TimezoneAwareDateTime)
    refresh_flag = Column(Boolean)
    first_added_datetime = Column(DateTime)
    weeks_52_high = Column(Float)
    weeks_52_low = Column(Float)
    symbol = Column(String)
    short_name = Column(String)
    mfill = Column(String)
